==> Java-Swing-0.03.tar.gz: Java-Swing-0.03/java/PerlComponentListener.java <==
import java.awt.event.ComponentListener;
import org.perl.inline.java.*;

public class      PerlComponentListener
       extends    InlineJavaPerlCaller
       implements ComponentListener
{
    String sender;
    String callbacks;

    public PerlComponentListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void componentResized(java.awt.event.ComponentEvent event) {
        try {
            CallPerl(
                "Java::Swing::ComponentListener",
                "_ComponentListener",
                new Object[] {sender, callbacks, "componentResized", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void componentMoved(java.awt.event.ComponentEvent event) {
        try {
            CallPerl(
                "Java::Swing::ComponentListener",
                "_ComponentListener",
                new Object[] {sender, callbacks, "componentMoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void componentShown(java.awt.event.ComponentEvent event) {
        try {
            CallPerl(
                "Java::Swing::ComponentListener",
                "_ComponentListener",
                new Object[] {sender, callbacks, "componentShown", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void componentHidden(java.awt.event.ComponentEvent event) {
        try {
            CallPerl(
                "Java::Swing::ComponentListener",
                "_ComponentListener",
                new Object[] {sender, callbacks, "componentHidden", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.14.tar.gz: Java-Swing-0.14/java/PerlComponentListener.java <==
import java.awt.event.ComponentListener;
import org.perl.inline.java.*;

public class      PerlComponentListener
       extends    InlineJavaPerlCaller
       implements ComponentListener
{
    String sender;
    String callbacks;

    public PerlComponentListener() throws InlineJavaException { }

    public PerlComponentListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void componentResized(java.awt.event.ComponentEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "componentResized", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void componentMoved(java.awt.event.ComponentEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "componentMoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void componentShown(java.awt.event.ComponentEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "componentShown", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void componentHidden(java.awt.event.ComponentEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "componentHidden", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
